# GenAI Processors library

[![PyPI version](https://img.shields.io/pypi/v/genai-processors.svg)](https://pypi.org/project/genai-processors/)
![Python support](https://img.shields.io/pypi/pyversions/genai-processors)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/genai-processors)](https://pypistats.org/packages/genai-processors)


--------
**Documentation:** https://github.com/google-gemini/genai-processors

-----

**Build Modular, Asynchronous, and Composable AI Pipelines for Generative AI.**

GenAI Processors is a lightweight Python library that enables efficient,
parallel content processing.

## Installation

```sh
pip install genai-processors
```

## Imports

```python
from genai_processors import content_api
from genai_processors import processor
from genai_processors import streams
from genai_processors.core import genai_model
...
```